;; Generated package description from mpdired.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "mpdired" "3.0.20250314.151545" "A dired-like client for Music Player Daemon" '((emacs "29")) :commit "793ec28c47d25f36806eb5e692025d61fb6a1bb3" :url "https://elpa.gnu.org/packages/mpdired.html" :authors '(("Manuel Giraud" . "manuel@ledu-giraud.fr")) :maintainer '("Manuel Giraud" . "manuel@ledu-giraud.fr") :keywords '("multimedia"))
